$logfile = "c:\programdata\installs.txt"
$logfile_verbose = "c:\programdata\verbose.txt"

function log($s, $verbose=$false)
{
    $t = Get-Date -Format "dd.MM.yyyy - HH:mm:ss.ff"
    if (!$verbose) {
        Add-Content $logfile -Value "$t - $s"
    }
    Add-Content $logfile_verbose -Value "$t - $s"
    Write-Host "$t - $s"
}

# Change to the script directory in case this script was called from somewhere else
cd $PSScriptRoot\customization

log "Performing customization"

log "  Importing Security baselines"

log "    BitLocker"
.\lgpo /t .\bitlocker.txt | Out-Null
log "      Result $LASTEXITCODE"

log "    Computer"
.\lgpo /t .\computer.txt | Out-Null
log "      Result $LASTEXITCODE"

log "    IE (Computer)"
.\lgpo /t .\ie_computer.txt | Out-Null
log "      Result $LASTEXITCODE"

log "    Credential Guard"
.\lgpo /t .\credentialguard.txt | Out-Null
log "      Result $LASTEXITCODE"

log "    Windows Defender"
.\lgpo /t .\defender.txt | Out-Null
log "      Result $LASTEXITCODE"

log "    Edge"
.\lgpo /t .\edge.txt | Out-Null
log "      Result $LASTEXITCODE"

log "    CIS"
.\lgpo /t .\cis.txt | Out-Null
log "      Result $LASTEXITCODE"

log "    Custom"
.\lgpo /t .\custom.txt | Out-Null
log "      Result $LASTEXITCODE"

log "    IE (User)"
.\lgpo /t .\ie_user.txt | Out-Null
log "      Result $LASTEXITCODE"

log "    User"
.\lgpo /t .\user.txt | Out-Null
log "      Result $LASTEXITCODE"

log "  Set additional hardening rules" $true
New-Item HKLM:\SYSTEM\CurrentControlSet\Control\Network\NewNetworkWindowOff

log "  Set hardening rules from Swiss Post" $true
log "    Registry keys" $true

[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows\CurrentVersion\Policies\Explorer", "NoAddPrinter", 1)
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\Print\Providers\LanMan Print Services\Servers", "AddPrinterDrivers", 1)
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\RemoteRegistry", "Start", 4)
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows NT\CurrentVersion\Setup\RecoveryConsole", "SecurityLevel", 0)
#[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\Software\Microsoft\Windows\CurrentVersion\Policies\Explorer", "NoRun", 1)
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Policies\Microsoft\WindowsFirewall\PrivateProfile", "DefaultInboundAction", 1)
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Policies\Microsoft\WindowsFirewall\PrivateProfile", "DoNotAllowExceptions", 1)
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Policies\Microsoft\WindowsFirewall\PublicProfile", "DefaultInboundAction", 1)
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Policies\Microsoft\WindowsFirewall\PublicProfile", "DoNotAllowExceptions", 1)
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Policies\Microsoft\WindowsFirewall\DomainProfile", "DefaultInboundAction", 1)
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Policies\Microsoft\WindowsFirewall\DomainProfile", "DoNotAllowExceptions", 1)
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\TCPIP6\Parameters", "DisabledComponents", 0xffffffff)
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Policies\Microsoft\Windows\Network Connections", "NC_ShowSharedAccessUI", 0)
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\Tcpip\Parameters", "EnableICMPRedirect", 0)
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows\CurrentVersion\Policies\System", "NoConnectedUser", 3)
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\PolicyManager\default\Settings\AllowYourAccount", "value", 0)
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows\CurrentVersion\Policies\System", "EnableLUA", 1)
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows\CurrentVersion\Policies\System", "ConsentPromptBehaviorAdmin", 2)

log "    Disable Teredo" $true
netsh interface teredo set state disabled
log "      Result $LASTEXITCODE" $true

log "    Configure Sleep Mode" $true
powercfg /x standby-timeout-ac 0 | Out-Null
log "      Standby AC $LASTEXITCODE" $true
powercfg /x standby-timeout-dc 0 | Out-Null
log "      Standby DC $LASTEXITCODE" $true
powercfg /x hibernate-timeout-ac 0 | Out-Null
log "      Hibernate AC $LASTEXITCODE" $true
powercfg /x hibernate-timeout-dc 0 | Out-Null
log "      Hibernate DC $LASTEXITCODE" $true
powercfg /x monitor-timeout-ac 2700 | Out-Null
log "      Monitor $LASTEXITCODE" $true

log "    Set maximum password age"
net accounts /maxpwage:120 | Out-Null
log "      Result $LASTEXITCODE"

log "    Disable Guest User" $true
net user Gast /active:no | Out-Null
log "      Result $LASTEXITCODE" $true

log "    Changing Audit Policy" $true
auditpol /set /subcategory:"Authentifizierungsrichtliniennderung" /success:enable /failure:disable | Out-Null
log "      Authentication: $LASTEXITCODE" $true
auditpol /set /subcategory:"Autorisierungsrichtliniennderung" /success:enable /failure:enable | Out-Null
log "      Authorization: $LASTEXITCODE" $true
auditpol /set /subcategory:"Richtliniennderungen berwachen" /success:enable /failure:enable | Out-Null
log "      Policy Change: $LASTEXITCODE" $true
auditpol /set /subcategory:"berprfung der Anmeldeinformationen" /success:enable /failure:enable | Out-Null
log "      Logon: $LASTEXITCODE" $true
auditpol /set /subcategory:"Anwendungsgruppenverwaltung" /success:enable /failure:enable | Out-Null
log "      Application Group: $LASTEXITCODE" $true
auditpol /set /subcategory:"Plug & Play-Ereignisse" /success:enable /failure:enable | Out-Null
log "      PnP: $LASTEXITCODE" $true
auditpol /set /subcategory:"Prozesserstellung" /success:enable /failure:enable | Out-Null
log "      Process Creation: $LASTEXITCODE" $true
auditpol /set /subcategory:"Kontosperrung" /success:enable /failure:enable | Out-Null
log "      Account Lock: $LASTEXITCODE" $true
auditpol /set /subcategory:"Gruppenmitgliedschaft" /success:enable /failure:enable | Out-Null
log "      Group Membership: $LASTEXITCODE" $true
auditpol /set /subcategory:"Andere Anmelde-/Abmeldeereignisse" /success:enable /failure:enable | Out-Null
log "      Other Logon: $LASTEXITCODE" $true
auditpol /set /subcategory:"Detaillierte Dateifreigabe" /success:enable /failure:enable | Out-Null
log "      Detailed Share: $LASTEXITCODE" $true
auditpol /set /subcategory:"Dateifreigabe" /success:enable /failure:enable | Out-Null
log "      File Share: $LASTEXITCODE" $true
auditpol /set /subcategory:"Andere Objektzugriffsereignisse" /success:enable /failure:enable | Out-Null
log "      Object Access: $LASTEXITCODE" $true
auditpol /set /subcategory:"Wechselmedien" /success:enable /failure:enable | Out-Null
log "      Media: $LASTEXITCODE" $true
auditpol /set /subcategory:"MPSSVC-Richtliniennderung auf Regelebene" /success:enable /failure:enable | Out-Null
log "      MPSSVC: $LASTEXITCODE" $true
auditpol /set /subcategory:"Andere Richtliniennderungsereignisse" /success:disable /failure:enable | Out-Null
log "      Other Policies: $LASTEXITCODE" $true
auditpol /set /subcategory:"Sensible Verwendung von Rechten" /success:enable /failure:enable | Out-Null
log "      Sensitive Permissions: $LASTEXITCODE" $true
auditpol /set /subcategory:"IPSEC-Treiber" /success:enable /failure:enable | Out-Null
log "      IPSEC: $LASTEXITCODE" $true
auditpol /set /subcategory:"Sicherheitssystemerweiterung" /success:enable /failure:enable | Out-Null
log "      Security System: $LASTEXITCODE" $true

log "    Disable WinRE"
reagentc.exe /disable | Out-Null
log "    Result $LASTEXITCODE"

log "    Block ICMP" $true
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Policies\Microsoft\WindowsFirewall\FirewallRules", "Custom-Block-ICMPv4", "v2.30|Action=Block|Active=TRUE|Dir=Out|Protocol=1|Name=Block ICMPv4|")
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Policies\Microsoft\WindowsFirewall\FirewallRules", "Custom-Block-ICMPv6", "v2.30|Action=Block|Active=TRUE|Dir=Out|Protocol=58|Name=Block ICMPv6|")

log "  Allow time change for users" $true
secedit /configure /db c:\windows\system32\customsecedit.sdb /cfg timechangeforusers.inf /areas USER_RIGHTS /overwrite /quiet | Out-Null
log "    Result $LASTEXITCODE" $true

log "  Modify default user profile"
reg load "HKU\Default" "C:\Users\Default\NTUSER.DAT" | Out-Null
log "    Loading $LASTEXITCODE"
[Microsoft.Win32.Registry]::SetValue("HKEY_USERS\Default\SOFTWARE\Microsoft\Windows\CurrentVersion\Explorer", "EnableAutoTray", 0)
[Microsoft.Win32.Registry]::SetValue("HKEY_USERS\Default\SOFTWARE\Microsoft\Windows\CurrentVersion\Explorer\Advanced", "HideFileExt", 0)
[Microsoft.Win32.Registry]::SetValue("HKEY_USERS\Default\SOFTWARE\Microsoft\Windows\CurrentVersion\Explorer\Advanced", "Hidden", 1)
[Microsoft.Win32.Registry]::SetValue("HKEY_USERS\Default\SOFTWARE\Microsoft\Windows\CurrentVersion\Search", "SearchboxTaskbarMode", 0)
[Microsoft.Win32.Registry]::SetValue("HKEY_USERS\Default\SOFTWARE\Sysinternals\SDelete", "EulaAccepted", 1)
reg unload "HKU\Default" | Out-Null
log "    Saving $LASTEXITCODE"

log "  Configuring start menu layout"
cp .\LayoutModification.xml C:\Users\Default\AppData\Local\Microsoft\Windows\Shell
log "    Done"

log "  Set file type associations"
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Classes\NotepadPP_file", "", "Notepad++ Document")
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Classes\NotepadPP_file", "DefaultIcon", '"C:\Program Files\Notepad++\notepad++.exe",0')
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Classes\NotepadPP_file\shell\open\command", "", '"C:\Program Files\Notepad++\notepad++.exe" "%1"')
$fileTypes = @('.ini', '.config', '.properties', '.xml', '.xconf', '.log', '.inf', '.manifest', '.java', '.nfo', '.conf', '.cnf')
foreach ($fileType in $fileTypes) {
    [Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\SOFTWARE\Classes\$fileType", "", "NotepadPP_file")
}
log "    Done"

log "  Block outbound network connections on firewall"
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\Software\Microsoft\Windows\CurrentVersion\RunOnce", `
    "!Firewall", "netsh.exe advfirewall set allprofiles firewallpolicy blockinbound,blockoutbound")

log "  Remove Windows User Experience Pack"
dism /online /remove-package /packagename:Microsoft-Windows-UserExperience-Desktop-Package~31bf3856ad364e35~amd64~~10.0.19041.1266 | Out-Null
log "    Result $LASTEXITCODE"

log "  Staging postcustomization scripts" $true
cp .\bitlocker.ps1 C:\Windows
cp .\postcustomization.ps1 C:\Windows
cp .\check-biosupdatestatus.ps1 C:\Windows
[Microsoft.Win32.Registry]::SetValue("HKEY_LOCAL_MACHINE\Software\Microsoft\Windows\CurrentVersion\RunOnce", `
    "!PostCustomization", "powershell.exe -file c:\windows\postcustomization.ps1")

sleep 15

# SIG # Begin signature block
# MIIpIwYJKoZIhvcNAQcCoIIpFDCCKRACAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCAVmDudpeReqH0D
# pj3fG2qU/24QlEudMgkIE95rlmqD1qCCDiAwggawMIIEmKADAgECAhAIrUCyYNKc
# TJ9ezam9k67ZMA0GCSqGSIb3DQEBDAUAMGIxCzAJBgNVBAYTAlVTMRUwEwYDVQQK
# EwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2VydC5jb20xITAfBgNV
# BAMTGERpZ2lDZXJ0IFRydXN0ZWQgUm9vdCBHNDAeFw0yMTA0MjkwMDAwMDBaFw0z
# NjA0MjgyMzU5NTlaMGkxCzAJBgNVBAYTAlVTMRcwFQYDVQQKEw5EaWdpQ2VydCwg
# SW5jLjFBMD8GA1UEAxM4RGlnaUNlcnQgVHJ1c3RlZCBHNCBDb2RlIFNpZ25pbmcg
# UlNBNDA5NiBTSEEzODQgMjAyMSBDQTEwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAw
# ggIKAoICAQDVtC9C0CiteLdd1TlZG7GIQvUzjOs9gZdwxbvEhSYwn6SOaNhc9es0
# JAfhS0/TeEP0F9ce2vnS1WcaUk8OoVf8iJnBkcyBAz5NcCRks43iCH00fUyAVxJr
# Q5qZ8sU7H/Lvy0daE6ZMswEgJfMQ04uy+wjwiuCdCcBlp/qYgEk1hz1RGeiQIXhF
# LqGfLOEYwhrMxe6TSXBCMo/7xuoc82VokaJNTIIRSFJo3hC9FFdd6BgTZcV/sk+F
# LEikVoQ11vkunKoAFdE3/hoGlMJ8yOobMubKwvSnowMOdKWvObarYBLj6Na59zHh
# 3K3kGKDYwSNHR7OhD26jq22YBoMbt2pnLdK9RBqSEIGPsDsJ18ebMlrC/2pgVItJ
# wZPt4bRc4G/rJvmM1bL5OBDm6s6R9b7T+2+TYTRcvJNFKIM2KmYoX7BzzosmJQay
# g9Rc9hUZTO1i4F4z8ujo7AqnsAMrkbI2eb73rQgedaZlzLvjSFDzd5Ea/ttQokbI
# YViY9XwCFjyDKK05huzUtw1T0PhH5nUwjewwk3YUpltLXXRhTT8SkXbev1jLchAp
# QfDVxW0mdmgRQRNYmtwmKwH0iU1Z23jPgUo+QEdfyYFQc4UQIyFZYIpkVMHMIRro
# OBl8ZhzNeDhFMJlP/2NPTLuqDQhTQXxYPUez+rbsjDIJAsxsPAxWEQIDAQABo4IB
# WTCCAVUwEgYDVR0TAQH/BAgwBgEB/wIBADAdBgNVHQ4EFgQUaDfg67Y7+F8Rhvv+
# YXsIiGX0TkIwHwYDVR0jBBgwFoAU7NfjgtJxXWRM3y5nP+e6mK4cD08wDgYDVR0P
# AQH/BAQDAgGGMBMGA1UdJQQMMAoGCCsGAQUFBwMDMHcGCCsGAQUFBwEBBGswaTAk
# BggrBgEFBQcwAYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29tMEEGCCsGAQUFBzAC
# hjVodHRwOi8vY2FjZXJ0cy5kaWdpY2VydC5jb20vRGlnaUNlcnRUcnVzdGVkUm9v
# dEc0LmNydDBDBgNVHR8EPDA6MDigNqA0hjJodHRwOi8vY3JsMy5kaWdpY2VydC5j
# b20vRGlnaUNlcnRUcnVzdGVkUm9vdEc0LmNybDAcBgNVHSAEFTATMAcGBWeBDAED
# MAgGBmeBDAEEATANBgkqhkiG9w0BAQwFAAOCAgEAOiNEPY0Idu6PvDqZ01bgAhql
# +Eg08yy25nRm95RysQDKr2wwJxMSnpBEn0v9nqN8JtU3vDpdSG2V1T9J9Ce7FoFF
# UP2cvbaF4HZ+N3HLIvdaqpDP9ZNq4+sg0dVQeYiaiorBtr2hSBh+3NiAGhEZGM1h
# mYFW9snjdufE5BtfQ/g+lP92OT2e1JnPSt0o618moZVYSNUa/tcnP/2Q0XaG3Ryw
# YFzzDaju4ImhvTnhOE7abrs2nfvlIVNaw8rpavGiPttDuDPITzgUkpn13c5Ubdld
# AhQfQDN8A+KVssIhdXNSy0bYxDQcoqVLjc1vdjcshT8azibpGL6QB7BDf5WIIIJw
# 8MzK7/0pNVwfiThV9zeKiwmhywvpMRr/LhlcOXHhvpynCgbWJme3kuZOX956rEnP
# LqR0kq3bPKSchh/jwVYbKyP/j7XqiHtwa+aguv06P0WmxOgWkVKLQcBIhEuWTatE
# QOON8BUozu3xGFYHKi8QxAwIZDwzj64ojDzLj4gLDb879M4ee47vtevLt/B3E+bn
# KD+sEq6lLyJsQfmCXBVmzGwOysWGw/YmMwwHS6DTBwJqakAwSEs0qFEgu60bhQji
# WQ1tygVQK+pKHJ6l/aCnHwZ05/LWUpD9r4VIIflXO7ScA+2GRfS0YW6/aOImYIbq
# yK+p/pQd52MbOoZWeE4wggdoMIIFUKADAgECAhAHm0XlRx2dupD0A91/gwV9MA0G
# CSqGSIb3DQEBCwUAMGkxCzAJBgNVBAYTAlVTMRcwFQYDVQQKEw5EaWdpQ2VydCwg
# SW5jLjFBMD8GA1UEAxM4RGlnaUNlcnQgVHJ1c3RlZCBHNCBDb2RlIFNpZ25pbmcg
# UlNBNDA5NiBTSEEzODQgMjAyMSBDQTEwHhcNMjIwNzI4MDAwMDAwWhcNMjUwNjI4
# MjM1OTU5WjBtMQswCQYDVQQGEwJDSDEQMA4GA1UECBMHWnVlcmljaDEWMBQGA1UE
# BxMNQnJ1ZXR0aXNlbGxlbjESMBAGA1UEChMJT250cmV4IEFHMQwwCgYDVQQLEwND
# VE8xEjAQBgNVBAMTCU9udHJleCBBRzCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCC
# AgoCggIBAN/Ghk02PiOCEsIguFhKkxRt9SeEPQjb+xroF9t34LHul33L6VDYNDIo
# U/WKjTUWT7r/7WqvIEWB+jufC0BYGX0zMm+JW1eJvFWaQ+koKAm3TPY2M2AXkO4C
# KN3+rGAT4DOrC1zyT7w3YI4D9BkrAHd/2JU/NbvUQl/fjobALG4/36PMPGJmzE3y
# q+QKgImHBaZ7CsJ5hrFIuMBaiXoqH9gduSdd9sD986s+3VfzQMi5QrYnnYiJqRTL
# dABCufDQEOgn0R3gma2vrVaQlKXHKP91sGp2lCdNE1F61lpKKzzwAiN4OWhBxlNK
# 19xIg2OV90g53l2BlOK0sG2YVygfGZ/3Z5AF4Nbr/Ps4iVNY2lVW1OTBdpa4/1cO
# q0g4guOoCc8dwNnN99RUpMGlqHRfkc272w8Rzg1S3cwlqfvjie49lvlkK7HnlZxc
# SyI0bQnyk1vOZkPbXb903nmNehqM+BGGcBMKVfarB3XqCJFeedRaorK6gpGKz+Km
# fn4HmI3ENrd1crvhnae9KCOiaV6+F691f7OuyHnYYH2C3UhqMaUY4K4Y+GWlx6EY
# v0zAuKKoSAFNSYXZZipgvUlGSjpUeWw88uOJlJEv383g8DKMtIeguIu/SUgP7mSQ
# Xy525kSrZG3w+qK08q+lNrr6RmNxvSlhWQ+0NYbHsF8Vg66007KFAgMBAAGjggIG
# MIICAjAfBgNVHSMEGDAWgBRoN+Drtjv4XxGG+/5hewiIZfROQjAdBgNVHQ4EFgQU
# 1w/iYCFGy/sHJw0leNX7sZbgMbcwDgYDVR0PAQH/BAQDAgeAMBMGA1UdJQQMMAoG
# CCsGAQUFBwMDMIG1BgNVHR8Ega0wgaowU6BRoE+GTWh0dHA6Ly9jcmwzLmRpZ2lj
# ZXJ0LmNvbS9EaWdpQ2VydFRydXN0ZWRHNENvZGVTaWduaW5nUlNBNDA5NlNIQTM4
# NDIwMjFDQTEuY3JsMFOgUaBPhk1odHRwOi8vY3JsNC5kaWdpY2VydC5jb20vRGln
# aUNlcnRUcnVzdGVkRzRDb2RlU2lnbmluZ1JTQTQwOTZTSEEzODQyMDIxQ0ExLmNy
# bDA+BgNVHSAENzA1MDMGBmeBDAEEATApMCcGCCsGAQUFBwIBFhtodHRwOi8vd3d3
# LmRpZ2ljZXJ0LmNvbS9DUFMwgZQGCCsGAQUFBwEBBIGHMIGEMCQGCCsGAQUFBzAB
# hhhodHRwOi8vb2NzcC5kaWdpY2VydC5jb20wXAYIKwYBBQUHMAKGUGh0dHA6Ly9j
# YWNlcnRzLmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydFRydXN0ZWRHNENvZGVTaWduaW5n
# UlNBNDA5NlNIQTM4NDIwMjFDQTEuY3J0MAwGA1UdEwEB/wQCMAAwDQYJKoZIhvcN
# AQELBQADggIBAFYUSriK8lc6QRH6PqMcx0y5trKycljYdsWRQVMAz+/CjVbQMJeq
# enUHOy3wM+RwwuEcyRrYsCXNxHat9ghruP0s0qSDgOEHeWjG1ObP0sCk5sdFJTSg
# EnegZziW5NKjs1L/TsMYjOqdxytXoOoNvTM7dGf/YYHZ7/+9N+KpyarXNYIuDiKW
# 8ayvW+npsEGTWy/DiPl8RG9u8h38kPddeK/Fv53YbK7P5iOgskQqAeJBMr3o5ICs
# MVLGpYHsH+pRj5wRirj55L6fwdexp5sH2kSS4NOJR3W+ZYMuFiIiJJQuwjL4/A46
# cqB3M0MjtGy1hEQCnA4hNdvEGRQN71rj/Paa83LPZHkLCOe/oziTnrTeihYcy2OM
# dzfWwreUCGqYYVV9AWwiZ99w6YucRVch94e0+7A02pvLExcCZT+YrTHU6REHGoCk
# zgaVmD4OoakmDt1sl5COvlpbeX79SkuJYBoIefySepRewZnsbZurq4qwnWm1amRE
# heVoX/ONr+oqGH+MruOq4OQQce89VkhWNukI4wSyGKYG6/koOQNK0umm354ds+AA
# 2jhBirUSAio/+SQga9sFlElfxRd8FbZXOEYgDdRcF2GtrAwXvvFBZtubfm7h74Hm
# 3Sy0ID82UKP6HdzbiPUkxl6nuDwiWU9DistUfzLOUBzWz8AzW0onnrdzMYIaWTCC
# GlUCAQEwfTBpMQswCQYDVQQGEwJVUzEXMBUGA1UEChMORGlnaUNlcnQsIEluYy4x
# QTA/BgNVBAMTOERpZ2lDZXJ0IFRydXN0ZWQgRzQgQ29kZSBTaWduaW5nIFJTQTQw
# OTYgU0hBMzg0IDIwMjEgQ0ExAhAHm0XlRx2dupD0A91/gwV9MA0GCWCGSAFlAwQC
# AQUAoHwwEAYKKwYBBAGCNwIBDDECMAAwGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcC
# AQQwHAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIE
# IA8qI6OnlozNJgo1VlN8FXH5FUUgYTEpSdLJKOojr+iOMA0GCSqGSIb3DQEBAQUA
# BIICAN0lpqw1VjxCJdNTIRcD7UENxEbnYAJb+JLUJkNQlBTHT5oFnDPP8wuQ9dLs
# Kux4FY7i8/eV2L6FpqBmWx+2DNiSqTUJMxgbdy4esbyVcEQOMbhtAXjL4So1wYzj
# okWZPhT18A91bHAdbLkKYciKelQQ9R9Cpi8OSd/eJ1OKJRzRx/cBJoWg91I7/G1k
# HWLYk3ORNFe8rPZsilGENBZ146Ij/+DL3UOm6a3lEGvKima8CEqJUVPdPugZYggt
# aXq3XrDpoHPCrYGXrPalOOTo5AI1eU3T1a2EtE6s43SzFlSVCOXRAxbL3kpbvpLR
# 11VHDNhEX0q9WCaq6nAUQdFtU0dljlh/0LGXKJ9HmlbNvgSMVk3XSSOhipdisOdv
# RNXvTiNvvfO3KWDMbErWYccPqKhh6VUZiJiqzbj9fYHc2UrY+SEPUXVdqiU+D8qH
# BIioJNUOjo2kwQGy5Su3TNfupOZTSug9Lg8QtciiOL2w3IGmUNL8+P5tCMqSgZxw
# mzLtbzz5N4D4z3pNdAqVUL6sY+zXYLsiP/u9U5qRJ0mhj9QFx9xb7piczef2XNaH
# CK9mdL+yOgJk8BTNRnQeo7K5Vq1Jok9WbfHAqarL3WZN93Cb/MwhUVXnAKMW7GLx
# LqRcGO4GFzhkwhRRK1DIq3zxiByWd2+a8LNgd/jv9g89MY/EoYIXLzCCFysGCisG
# AQQBgjcDAwExghcbMIIXFwYJKoZIhvcNAQcCoIIXCDCCFwQCAQMxDzANBglghkgB
# ZQMEAgEFADBnBgsqhkiG9w0BCRABBKBYBFYwVAIBAQYJYIZIAYb9bAcBMCEwCQYF
# Kw4DAhoFAAQUiG0XRkpE+cXKgWzgBmEslYgrMs8CEBqdE22lC1secTZjj0xAnpIY
# DzIwMjQwOTIzMTEzODIzWqCCEwkwggbCMIIEqqADAgECAhAFRK/zlJ0IOaa/2z9f
# 5WEWMA0GCSqGSIb3DQEBCwUAMGMxCzAJBgNVBAYTAlVTMRcwFQYDVQQKEw5EaWdp
# Q2VydCwgSW5jLjE7MDkGA1UEAxMyRGlnaUNlcnQgVHJ1c3RlZCBHNCBSU0E0MDk2
# IFNIQTI1NiBUaW1lU3RhbXBpbmcgQ0EwHhcNMjMwNzE0MDAwMDAwWhcNMzQxMDEz
# MjM1OTU5WjBIMQswCQYDVQQGEwJVUzEXMBUGA1UEChMORGlnaUNlcnQsIEluYy4x
# IDAeBgNVBAMTF0RpZ2lDZXJ0IFRpbWVzdGFtcCAyMDIzMIICIjANBgkqhkiG9w0B
# AQEFAAOCAg8AMIICCgKCAgEAo1NFhx2DjlusPlSzI+DPn9fl0uddoQ4J3C9Io5d6
# OyqcZ9xiFVjBqZMRp82qsmrdECmKHmJjadNYnDVxvzqX65RQjxwg6seaOy+WZuNp
# 52n+W8PWKyAcwZeUtKVQgfLPywemMGjKg0La/H8JJJSkghraarrYO8pd3hkYhftF
# 6g1hbJ3+cV7EBpo88MUueQ8bZlLjyNY+X9pD04T10Mf2SC1eRXWWdf7dEKEbg8G4
# 5lKVtUfXeCk5a+B4WZfjRCtK1ZXO7wgX6oJkTf8j48qG7rSkIWRw69XloNpjsy7p
# Be6q9iT1HbybHLK3X9/w7nZ9MZllR1WdSiQvrCuXvp/k/XtzPjLuUjT71Lvr1KAs
# NJvj3m5kGQc3AZEPHLVRzapMZoOIaGK7vEEbeBlt5NkP4FhB+9ixLOFRr7StFQYU
# 6mIIE9NpHnxkTZ0P387RXoyqq1AVybPKvNfEO2hEo6U7Qv1zfe7dCv95NBB+plwK
# WEwAPoVpdceDZNZ1zY8SdlalJPrXxGshuugfNJgvOuprAbD3+yqG7HtSOKmYCaFx
# smxxrz64b5bV4RAT/mFHCoz+8LbH1cfebCTwv0KCyqBxPZySkwS0aXAnDU+3tTbR
# yV8IpHCj7ArxES5k4MsiK8rxKBMhSVF+BmbTO77665E42FEHypS34lCh8zrTioPL
# QHsCAwEAAaOCAYswggGHMA4GA1UdDwEB/wQEAwIHgDAMBgNVHRMBAf8EAjAAMBYG
# A1UdJQEB/wQMMAoGCCsGAQUFBwMIMCAGA1UdIAQZMBcwCAYGZ4EMAQQCMAsGCWCG
# SAGG/WwHATAfBgNVHSMEGDAWgBS6FtltTYUvcyl2mi91jGogj57IbzAdBgNVHQ4E
# FgQUpbbvE+fvzdBkodVWqWUxo97V40kwWgYDVR0fBFMwUTBPoE2gS4ZJaHR0cDov
# L2NybDMuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0VHJ1c3RlZEc0UlNBNDA5NlNIQTI1
# NlRpbWVTdGFtcGluZ0NBLmNybDCBkAYIKwYBBQUHAQEEgYMwgYAwJAYIKwYBBQUH
# MAGGGGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0LmNvbTBYBggrBgEFBQcwAoZMaHR0cDov
# L2NhY2VydHMuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0VHJ1c3RlZEc0UlNBNDA5NlNI
# QTI1NlRpbWVTdGFtcGluZ0NBLmNydDANBgkqhkiG9w0BAQsFAAOCAgEAgRrW3qCp
# tZgXvHCNT4o8aJzYJf/LLOTN6l0ikuyMIgKpuM+AqNnn48XtJoKKcS8Y3U623mzX
# 4WCcK+3tPUiOuGu6fF29wmE3aEl3o+uQqhLXJ4Xzjh6S2sJAOJ9dyKAuJXglnSoF
# eoQpmLZXeY/bJlYrsPOnvTcM2Jh2T1a5UsK2nTipgedtQVyMadG5K8TGe8+c+nji
# kxp2oml101DkRBK+IA2eqUTQ+OVJdwhaIcW0z5iVGlS6ubzBaRm6zxbygzc0brBB
# Jt3eWpdPM43UjXd9dUWhpVgmagNF3tlQtVCMr1a9TMXhRsUo063nQwBw3syYnhmJ
# A+rUkTfvTVLzyWAhxFZH7doRS4wyw4jmWOK22z75X7BC1o/jF5HRqsBV44a/rCcs
# QdCaM0qoNtS5cpZ+l3k4SF/Kwtw9Mt911jZnWon49qfH5U81PAC9vpwqbHkB3NpE
# 5jreODsHXjlY9HxzMVWggBHLFAx+rrz+pOt5Zapo1iLKO+uagjVXKBbLafIymrLS
# 2Dq4sUaGa7oX/cR3bBVsrquvczroSUa31X/MtjjA2Owc9bahuEMs305MfR5ocMB3
# CtQC4Fxguyj/OOVSWtasFyIjTvTs0xf7UGv/B3cfcZdEQcm4RtNsMnxYL2dHZeUb
# c7aZ+WssBkbvQR7w8F/g29mtkIBEr4AQQYowggauMIIElqADAgECAhAHNje3JFR8
# 2Ees/ShmKl5bMA0GCSqGSIb3DQEBCwUAMGIxCzAJBgNVBAYTAlVTMRUwEwYDVQQK
# EwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2VydC5jb20xITAfBgNV
# BAMTGERpZ2lDZXJ0IFRydXN0ZWQgUm9vdCBHNDAeFw0yMjAzMjMwMDAwMDBaFw0z
# NzAzMjIyMzU5NTlaMGMxCzAJBgNVBAYTAlVTMRcwFQYDVQQKEw5EaWdpQ2VydCwg
# SW5jLjE7MDkGA1UEAxMyRGlnaUNlcnQgVHJ1c3RlZCBHNCBSU0E0MDk2IFNIQTI1
# NiBUaW1lU3RhbXBpbmcgQ0EwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoIC
# AQDGhjUGSbPBPXJJUVXHJQPE8pE3qZdRodbSg9GeTKJtoLDMg/la9hGhRBVCX6SI
# 82j6ffOciQt/nR+eDzMfUBMLJnOWbfhXqAJ9/UO0hNoR8XOxs+4rgISKIhjf69o9
# xBd/qxkrPkLcZ47qUT3w1lbU5ygt69OxtXXnHwZljZQp09nsad/ZkIdGAHvbREGJ
# 3HxqV3rwN3mfXazL6IRktFLydkf3YYMZ3V+0VAshaG43IbtArF+y3kp9zvU5Emfv
# DqVjbOSmxR3NNg1c1eYbqMFkdECnwHLFuk4fsbVYTXn+149zk6wsOeKlSNbwsDET
# qVcplicu9Yemj052FVUmcJgmf6AaRyBD40NjgHt1biclkJg6OBGz9vae5jtb7IHe
# IhTZgirHkr+g3uM+onP65x9abJTyUpURK1h0QCirc0PO30qhHGs4xSnzyqqWc0Jo
# n7ZGs506o9UD4L/wojzKQtwYSH8UNM/STKvvmz3+DrhkKvp1KCRB7UK/BZxmSVJQ
# 9FHzNklNiyDSLFc1eSuo80VgvCONWPfcYd6T/jnA+bIwpUzX6ZhKWD7TA4j+s4/T
# Xkt2ElGTyYwMO1uKIqjBJgj5FBASA31fI7tk42PgpuE+9sJ0sj8eCXbsq11GdeJg
# o1gJASgADoRU7s7pXcheMBK9Rp6103a50g5rmQzSM7TNsQIDAQABo4IBXTCCAVkw
# EgYDVR0TAQH/BAgwBgEB/wIBADAdBgNVHQ4EFgQUuhbZbU2FL3MpdpovdYxqII+e
# yG8wHwYDVR0jBBgwFoAU7NfjgtJxXWRM3y5nP+e6mK4cD08wDgYDVR0PAQH/BAQD
# AgGGMBMGA1UdJQQMMAoGCCsGAQUFBwMIMHcGCCsGAQUFBwEBBGswaTAkBggrBgEF
# BQcwAYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29tMEEGCCsGAQUFBzAChjVodHRw
# Oi8vY2FjZXJ0cy5kaWdpY2VydC5jb20vRGlnaUNlcnRUcnVzdGVkUm9vdEc0LmNy
# dDBDBgNVHR8EPDA6MDigNqA0hjJodHRwOi8vY3JsMy5kaWdpY2VydC5jb20vRGln
# aUNlcnRUcnVzdGVkUm9vdEc0LmNybDAgBgNVHSAEGTAXMAgGBmeBDAEEAjALBglg
# hkgBhv1sBwEwDQYJKoZIhvcNAQELBQADggIBAH1ZjsCTtm+YqUQiAX5m1tghQuGw
# GC4QTRPPMFPOvxj7x1Bd4ksp+3CKDaopafxpwc8dB+k+YMjYC+VcW9dth/qEICU0
# MWfNthKWb8RQTGIdDAiCqBa9qVbPFXONASIlzpVpP0d3+3J0FNf/q0+KLHqrhc1D
# X+1gtqpPkWaeLJ7giqzl/Yy8ZCaHbJK9nXzQcAp876i8dU+6WvepELJd6f8oVInw
# 1YpxdmXazPByoyP6wCeCRK6ZJxurJB4mwbfeKuv2nrF5mYGjVoarCkXJ38SNoOeY
# +/umnXKvxMfBwWpx2cYTgAnEtp/Nh4cku0+jSbl3ZpHxcpzpSwJSpzd+k1OsOx0I
# SQ+UzTl63f8lY5knLD0/a6fxZsNBzU+2QJshIUDQtxMkzdwdeDrknq3lNHGS1yZr
# 5Dhzq6YBT70/O3itTK37xJV77QpfMzmHQXh6OOmc4d0j/R0o08f56PGYX/sr2H7y
# Rp11LB4nLCbbbxV7HhmLNriT1ObyF5lZynDwN7+YAN8gFk8n+2BnFqFmut1VwDop
# hrCYoCvtlUG3OtUVmDG0YgkPCr2B2RP+v6TR81fZvAT6gt4y3wSJ8ADNXcL50CN/
# AAvkdgIm2fBldkKmKYcJRyvmfxqkhQ/8mJb2VVQrH4D6wPIOK+XW+6kvRBVK5xMO
# Hds3OBqhK/bt1nz8MIIFjTCCBHWgAwIBAgIQDpsYjvnQLefv21DiCEAYWjANBgkq
# hkiG9w0BAQwFADBlMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMRGlnaUNlcnQgSW5j
# MRkwFwYDVQQLExB3d3cuZGlnaWNlcnQuY29tMSQwIgYDVQQDExtEaWdpQ2VydCBB
# c3N1cmVkIElEIFJvb3QgQ0EwHhcNMjIwODAxMDAwMDAwWhcNMzExMTA5MjM1OTU5
# WjBiMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMRGlnaUNlcnQgSW5jMRkwFwYDVQQL
# ExB3d3cuZGlnaWNlcnQuY29tMSEwHwYDVQQDExhEaWdpQ2VydCBUcnVzdGVkIFJv
# b3QgRzQwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQC/5pBzaN675F1K
# PDAiMGkz7MKnJS7JIT3yithZwuEppz1Yq3aaza57G4QNxDAf8xukOBbrVsaXbR2r
# snnyyhHS5F/WBTxSD1Ifxp4VpX6+n6lXFllVcq9ok3DCsrp1mWpzMpTREEQQLt+C
# 8weE5nQ7bXHiLQwb7iDVySAdYyktzuxeTsiT+CFhmzTrBcZe7FsavOvJz82sNEBf
# sXpm7nfISKhmV1efVFiODCu3T6cw2Vbuyntd463JT17lNecxy9qTXtyOj4DatpGY
# QJB5w3jHtrHEtWoYOAMQjdjUN6QuBX2I9YI+EJFwq1WCQTLX2wRzKm6RAXwhTNS8
# rhsDdV14Ztk6MUSaM0C/CNdaSaTC5qmgZ92kJ7yhTzm1EVgX9yRcRo9k98FpiHaY
# dj1ZXUJ2h4mXaXpI8OCiEhtmmnTK3kse5w5jrubU75KSOp493ADkRSWJtppEGSt+
# wJS00mFt6zPZxd9LBADMfRyVw4/3IbKyEbe7f/LVjHAsQWCqsWMYRJUadmJ+9oCw
# ++hkpjPRiQfhvbfmQ6QYuKZ3AeEPlAwhHbJUKSWJbOUOUlFHdL4mrLZBdd56rF+N
# P8m800ERElvlEFDrMcXKchYiCd98THU/Y+whX8QgUWtvsauGi0/C1kVfnSD8oR7F
# wI+isX4KJpn15GkvmB0t9dmpsh3lGwIDAQABo4IBOjCCATYwDwYDVR0TAQH/BAUw
# AwEB/zAdBgNVHQ4EFgQU7NfjgtJxXWRM3y5nP+e6mK4cD08wHwYDVR0jBBgwFoAU
# Reuir/SSy4IxLVGLp6chnfNtyA8wDgYDVR0PAQH/BAQDAgGGMHkGCCsGAQUFBwEB
# BG0wazAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29tMEMGCCsG
# AQUFBzAChjdodHRwOi8vY2FjZXJ0cy5kaWdpY2VydC5jb20vRGlnaUNlcnRBc3N1
# cmVkSURSb290Q0EuY3J0MEUGA1UdHwQ+MDwwOqA4oDaGNGh0dHA6Ly9jcmwzLmRp
# Z2ljZXJ0LmNvbS9EaWdpQ2VydEFzc3VyZWRJRFJvb3RDQS5jcmwwEQYDVR0gBAow
# CDAGBgRVHSAAMA0GCSqGSIb3DQEBDAUAA4IBAQBwoL9DXFXnOF+go3QbPbYW1/e/
# Vwe9mqyhhyzshV6pGrsi+IcaaVQi7aSId229GhT0E0p6Ly23OO/0/4C5+KH38nLe
# JLxSA8hO0Cre+i1Wz/n096wwepqLsl7Uz9FDRJtDIeuWcqFItJnLnU+nBgMTdydE
# 1Od/6Fmo8L8vC6bp8jQ87PcDx4eo0kxAGTVGamlUsLihVo7spNU96LHc/RzY9Hda
# XFSMb++hUD38dglohJ9vytsgjTVgHAIDyyCwrFigDkBjxZgiwbJZ9VVrzyerbHbO
# byMt9H5xaiNrIv8SuFQtJ37YOtnwtoeW/VvRXKwYw02fc7cBqZ9Xql4o4rmUMYID
# djCCA3ICAQEwdzBjMQswCQYDVQQGEwJVUzEXMBUGA1UEChMORGlnaUNlcnQsIElu
# Yy4xOzA5BgNVBAMTMkRpZ2lDZXJ0IFRydXN0ZWQgRzQgUlNBNDA5NiBTSEEyNTYg
# VGltZVN0YW1waW5nIENBAhAFRK/zlJ0IOaa/2z9f5WEWMA0GCWCGSAFlAwQCAQUA
# oIHRMBoGCSqGSIb3DQEJAzENBgsqhkiG9w0BCRABBDAcBgkqhkiG9w0BCQUxDxcN
# MjQwOTIzMTEzODIzWjArBgsqhkiG9w0BCRACDDEcMBowGDAWBBRm8CsywsLJD4Jd
# zqqKycZPGZzPQDAvBgkqhkiG9w0BCQQxIgQgBCqalRN+rQ1F2sho+87pMPhwJfHM
# GcsV9ZS+bXiH4MIwNwYLKoZIhvcNAQkQAi8xKDAmMCQwIgQg0vbkbe10IszR1EBX
# aEE2b4KK2lWarjMWr00amtQMeCgwDQYJKoZIhvcNAQEBBQAEggIAhgPxL6y2vIoY
# vYJedMnabP47gL4jEBYCDM6HAJD8L6Hdt5t61yaZReHubBWac93iKP5asE5fxoZg
# ZWkoULjPeMWcfw0CA2haZTkZnJq207CFo8hz9AHMohy6yNEdWVts7hi/CAlh1raI
# 3aZmSa26DAEK23jDPd8w/0SXS5Dh20Pts3D+LBi99145cts1VQ67OMjq66/474AJ
# NqotePaIf0bXouXLJYAZpJcVC8O7JD1OdbxraZp7+7OHAz5CWCOtoOVUQg/1d+ef
# QIex4CD1GJd57VZUmzsF3X39eSXhTouLJH3fPK+b+cREkogmHqZPsUBNtoys7Uvw
# M/H+MKPoLfEcJzGU7GeSc8cOfYutW2QLlkQE4dKl2LQYATLC1VHsNUlO8ptw95l1
# dJhQVTIpK3WshQop6hlhby3SGeWXtfynYJKSmnJ6lTLH2prGXMr7wtw0aoTU493/
# ggoRcloewe2++wbXO6qdmcnmK0aBiEC+87kYWFe8aOPCPA4TleFsNsmB3tXCkaPk
# fre9cVaIQyCLk1TLsAk4f9FYcvQ6royh/FLZcxH/vzziPaIR3JPL6tNl9Xez2YD4
# R/fo+NHh6CZF4Iz0icWYu05eZfxFxUW+FvRGmatitc0ELsXjV2z1tCG5JWujHhez
# zD/KhWTtdm3/DGefT332rPvhsg2u5Is=
# SIG # End signature block
